@@ -1,7 +1,7 @@
 package Spreadsheet::HTML;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
@@ -80,6 +80,19 @@ sub generate {
         $args{data} = [ CORE::reverse @{ Math::Matrix::transpose( $args{data} ) }];
     }
 
+    if ($args{animate}) {
+        my ($js, %new_args) = Spreadsheet::HTML::Presets::animate(
+            %args,
+            data => [ map [ map $_->{cdata}, @$_ ], @{ $args{data} } ],
+        );
+        for (keys %args) {
+            if (ref $args{$_} eq 'HASH') {
+                $new_args{$_} = { %{ $new_args{$_} || {} }, %{ $args{$_} || {} } };
+            }
+        }
+        return $js . _make_table( _process( %new_args ) );
+    }
+
     return _make_table( %args );
 }
 
@@ -356,7 +369,7 @@ generating methods below:
 =item * C<north( %params )>
 
 =for html
-<table cellspacing="10" style="border: 1px dashed #A0A0A0"><tr style="color: #505050"><td>heading1</td><td>heading2</td><td>heading3</td></tr><tr style="color: #A0A0A0"><td>row1col1</td><td>row1col2</td><td>row1col3</td></tr><tr style="color: #A0A0A0"><td>row2col1</td><td>row2col2</td><td>row2col3</td></tr><tr style="color: #A0A0A0"><td>row3col1</td><td>row3col2</td><td>row3col3</td></tr></table>
+<table style="border: 1px dashed #A0A0A0"><tr><td><b>&nbsp;&nbsp;heading1&nbsp;&nbsp;</b></td><td><b>&nbsp;&nbsp;heading2&nbsp;&nbsp;</b></td><td><b>&nbsp;&nbsp;heading3&nbsp;&nbsp;</b></td><td><b>&nbsp;&nbsp;heading4&nbsp;&nbsp;</b></td></tr><tr><td>&nbsp;&nbsp;row1col1&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row1col2&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row1col3&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row1col4&nbsp;&nbsp;</td></tr><tr><td>&nbsp;&nbsp;row2col1&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col2&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col3&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col4&nbsp;&nbsp;</td></tr><tr><td>&nbsp;&nbsp;row3col1&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col2&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col3&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col4&nbsp;&nbsp;</td></tr></table>
 
   $html = $table->generate( table => {border => 1}, encode => '<>' );
   print Spreadsheet::HTML::generate( data => $data, indent => "\t" );
@@ -371,7 +384,7 @@ calls C<generate> like so:
 =item * C<west( %params )>
 
 =for html
-<table cellspacing="10" style="border: 1px dashed #A0A0A0"><tr style="color: #A0A0A0"><td style="color: #505050">heading1</td><td>row1col1</td><td>row2col1</td><td>row3col1</td></tr><tr style="color: #A0A0A0"><td style="color: #505050">heading2</td><td>row1col2</td><td>row2col2</td><td>row3col2</td></tr><tr style="color: #A0A0A0"><td style="color: #505050">heading3</td><td>row1col3</td><td>row2col3</td><td>row3col3</td></tr></table>
+<table style="border: 1px dashed #A0A0A0"><tr><td><b>&nbsp;&nbsp;heading1&nbsp;&nbsp;</b></td><td>&nbsp;&nbsp;row1col1&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col1&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col1&nbsp;&nbsp;</td></tr><tr><td><b>&nbsp;&nbsp;heading2&nbsp;&nbsp;</b></td><td>&nbsp;&nbsp;row1col2&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col2&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col2&nbsp;&nbsp;</td></tr><tr><td><b>&nbsp;&nbsp;heading3&nbsp;&nbsp;</b></td><td>&nbsp;&nbsp;row1col3&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col3&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col3&nbsp;&nbsp;</td></tr><tr><td><b>&nbsp;&nbsp;heading4&nbsp;&nbsp;</b></td><td>&nbsp;&nbsp;row1col4&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col4&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col4&nbsp;&nbsp;</td></tr></table>
 
 Headers on left. C<west()> is an alias for C<landscape()> which
 in turn calls C<generate> like so:
@@ -381,7 +394,7 @@ in turn calls C<generate> like so:
 =item * C<south( %params )>
 
 =for html
-<table cellspacing="10" style="border: 1px dashed #A0A0A0"><tr style="color: #A0A0A0"><td>row1col1</td><td>row1col2</td><td>row1col3</td></tr><tr style="color: #A0A0A0"><td>row2col1</td><td>row2col2</td><td>row2col3</td></tr><tr style="color: #A0A0A0"><td>row3col1</td><td>row3col2</td><td>row3col3</td></tr><tr style="color: #505050"><td>heading1</td><td>heading2</td><td>heading3</td></tr></table>
+<table style="border: 1px dashed #A0A0A0"><tr><td>&nbsp;&nbsp;row1col1&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row1col2&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row1col3&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row1col4&nbsp;&nbsp;</td></tr><tr><td>&nbsp;&nbsp;row2col1&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col2&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col3&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col4&nbsp;&nbsp;</td></tr><tr><td>&nbsp;&nbsp;row3col1&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col2&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col3&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col4&nbsp;&nbsp;</td></tr><tr><td><b>&nbsp;&nbsp;heading1&nbsp;&nbsp;</b></td><td><b>&nbsp;&nbsp;heading2&nbsp;&nbsp;</b></td><td><b>&nbsp;&nbsp;heading3&nbsp;&nbsp;</b></td><td><b>&nbsp;&nbsp;heading4&nbsp;&nbsp;</b></td></tr></table>
 
 Headers on bottom. Same as
 
@@ -390,7 +403,7 @@ Headers on bottom. Same as
 =item * C<east( %params )>
 
 =for html
-<table cellspacing="10" style="border: 1px dashed #A0A0A0"><tr style="color: #A0A0A0"><td>row1col1</td><td>row2col1</td><td>row3col1</td><td style="color: #505050">heading1</td></tr><tr style="color: #A0A0A0"><td>row1col2</td><td>row2col2</td><td>row3col2</td><td style="color: #505050">heading2</td></tr><tr style="color: #A0A0A0"><td>row1col3</td><td>row2col3</td><td>row3col3</td><td style="color: #505050">heading3</td></tr></table>
+<table style="border: 1px dashed #A0A0A0"><tr><td>&nbsp;&nbsp;row1col1&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col1&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col1&nbsp;&nbsp;</td><td><b>&nbsp;&nbsp;heading1&nbsp;&nbsp;</b></td></tr><tr><td>&nbsp;&nbsp;row1col2&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col2&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col2&nbsp;&nbsp;</td><td><b>&nbsp;&nbsp;heading2&nbsp;&nbsp;</b></td></tr><tr><td>&nbsp;&nbsp;row1col3&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col3&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col3&nbsp;&nbsp;</td><td><b>&nbsp;&nbsp;heading3&nbsp;&nbsp;</b></td></tr><tr><td>&nbsp;&nbsp;row1col4&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col4&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col4&nbsp;&nbsp;</td><td><b>&nbsp;&nbsp;heading4&nbsp;&nbsp;</b></td></tr></table>
 
 Headers on right. Same as
 
