@@ -10,6 +10,7 @@ sub _javascript {
     my $js = sprintf _js_tmpl(),
         $args{_max_rows},
         $args{_max_cols},
+        $args{interval},
         $args{off},
         join( ',', map "'$_'", @{ $args{colors} } ),
     ;
@@ -25,6 +26,8 @@ sub _js_tmpl {
 var MATRIX;
 var ROW = %s;
 var COL = %s;
+var INTERVAL = %s;
+var tid;
 
 function Cell (id) {
     this.id         = id;
@@ -59,6 +62,16 @@ function Cell (id) {
     }
 }
 
+function toggle() {
+    if ($('#toggle').html() === 'Start') {
+        tid = setInterval( update, INTERVAL );
+        $('#toggle').html( 'Stop' );
+    } else {
+        clearInterval( tid );
+        $('#toggle').html( 'Start' );
+    }
+}
+
 $(document).ready(function(){
 
     $('th.conway').click( function( data ) {
@@ -91,22 +104,9 @@ $(document).ready(function(){
 
 });
 
-function start() {
-    count();
-    update_matrix();
-}
-
-function update_matrix() {
-
-    for (var row = 0; row < ROW; row++) {
-        for (var col = 0; col < COL; col++) {
-            MATRIX[row][col].update();    
-        }
-    }
-}
-
-function count() {
+function update() {
 
+    // count neighbors
     for (var row = 0; row < ROW; row++) {
         for (var col = 0; col < COL; col++) {
 
@@ -124,6 +124,13 @@ function count() {
             }
         }
     }
+
+    // update cells
+    for (var row = 0; row < ROW; row++) {
+        for (var col = 0; col < COL; col++) {
+            MATRIX[row][col].update();    
+        }
+    }
 }
 END_JAVASCRIPT
 }
